@@ -16,6 +16,7 @@ FIELDS = [
     'categoryId',
     'CategoryName',
     'ClosePrice',
+    'currency',
     'distribution',
     'EffectiveDuration',
     'equityStyle',
@@ -23,7 +24,10 @@ FIELDS = [
     'ExpertiseAdvanced',
     'ExpertiseBasic',
     'ExpertiseInformed',
+    'exchangeCode',
+    'exchangeId'
     'FeeLevel',
+    'fundShareClassId',
     'fundSize',
     'fundStyle',
     'FundTNAV',
@@ -47,6 +51,7 @@ FIELDS = [
     'investmentExpertise',
     'investmentExpertise',
     'investmentObjective',
+    'investmentType',
     'investorType',
     'InvestorTypeEligibleCounterparty',
     'InvestorTypeProfessional',
@@ -91,6 +96,7 @@ FIELDS = [
     'SustainabilityRank',
     'sustainabilityRating',
     'TenforeId',
+    'ticker',
     'totalReturn',
     'totalReturnTimeFrame',
     'TrackRecordExtension',
